package pkg

import (
	"github.com/julienschmidt/httprouter"
	"net/http"
)

func serveTagsEditForm(w http.ResponseWriter, r *http.Request, params httprouter.Params, prefix string, sql string) {
	conn := getConn(r)
	locale := getLocale(r)
	company := getCompany(r)
	slug := params[0].Value
	if !ValidUuid(slug) {
		http.NotFound(w, r)
		return
	}
	form := newTagsForm(companyURI(company, prefix+slug+"/tags"), slug, locale)
	if notFoundErrorOrPanic(conn.QueryRow(r.Context(), sql, form.Slug).Scan(form.Tags)) {
		http.NotFound(w, r)
		return
	}
	mustRenderStandaloneTemplate(w, r, "tags/edit.gohtml", form)
}

type tagsForm struct {
	Action string
	Slug   string
	Tags   *TagsField
}

func newTagsForm(uri string, slug string, locale *Locale) *tagsForm {
	return &tagsForm{
		Action: uri,
		Slug:   slug,
		Tags: &TagsField{
			Name:  "tags-" + slug,
			Label: pgettext("input", "Tags", locale),
		},
	}
}

func (form *tagsForm) Parse(r *http.Request) error {
	if err := r.ParseForm(); err != nil {
		return err
	}
	form.Tags.FillValue(r)
	return nil
}

func handleUpdateTags(w http.ResponseWriter, r *http.Request, params httprouter.Params, prefix string, sql string) {
	locale := getLocale(r)
	conn := getConn(r)
	company := getCompany(r)
	slug := params[0].Value
	if !ValidUuid(slug) {
		http.NotFound(w, r)
		return
	}
	form := newTagsForm(companyURI(company, prefix+slug+"/tags/edit"), slug, locale)
	if err := form.Parse(r); err != nil {
		http.Error(w, err.Error(), http.StatusBadRequest)
		return
	}
	if err := verifyCsrfTokenValid(r); err != nil {
		http.Error(w, err.Error(), http.StatusForbidden)
		return
	}
	if conn.MustGetText(r.Context(), "", sql, form.Tags, form.Slug) == "" {
		http.NotFound(w, r)
		return
	}
	mustRenderStandaloneTemplate(w, r, "tags/view.gohtml", form)
}
